@@ -41,6 +41,8 @@
 
 #include <KCalUtils/RecurrenceActions>
 
+#include <KHolidays/HolidayRegion>
+
 #include <KCheckableProxyModel>
 #include <KGuiItem>
 #include <KLocalizedString>
@@ -107,10 +109,19 @@ void EventView::defaultAction(const Akonadi::Item &aitem)
     }
 }
 
-void EventView::setHolidayRegion(const KHolidays::HolidayRegionPtr &holidayRegion)
+void EventView::setHolidayRegions(const QStringList &regions)
 {
     Q_D(EventView);
-    d->mHolidayRegion = holidayRegion;
+    qDeleteAll(d->mHolidayRegions);
+    d->mHolidayRegions.clear();
+    foreach (const QString &regionStr, regions) {
+        KHolidays::HolidayRegion *region = new KHolidays::HolidayRegion(regionStr);
+        if (region->isValid()) {
+            d->mHolidayRegions.append(region);
+        } else {
+            delete region;
+        }
+    }
 }
 
 int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
@@ -144,6 +155,7 @@ int EventView::showMoveRecurDialog(const Incidence::Ptr &inc, const QDate &date)
             return KCalUtils::RecurrenceActions::questionSelectedFutureAllCancel(
                 message, caption, itemSelected, itemFuture, itemAll, this);
         }
+        Q_FALLTHROUGH();
 
     default:
         Q_ASSERT(availableOccurrences & KCalUtils::RecurrenceActions::SelectedOccurrence);
@@ -279,8 +291,7 @@ bool EventView::hasConfigurationDialog() const
     return false;
 }
 
-void EventView::setDateRange(const QDateTime &start, const QDateTime &end,
-                             const QDate &preferredMonth)
+void EventView::setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth)
 {
     Q_D(EventView);
 
@@ -471,7 +482,6 @@ QPair<QDateTime, QDateTime> EventView::actualDateRange(const QDateTime &start, c
 /*
 void EventView::incidencesAdded( const Akonadi::Item::List & )
 {
-
 }
 
 void EventView::incidencesAboutToBeRemoved( const Akonadi::Item::List & )
@@ -664,8 +674,7 @@ QString EventView::iconForItem(const Akonadi::Item &item)
     return iconName;
 }
 
-void EventView::onCollectionChanged(const Akonadi::Collection &collection,
-                                    const QSet<QByteArray> &changedAttributes)
+void EventView::onCollectionChanged(const Akonadi::Collection &collection, const QSet<QByteArray> &changedAttributes)
 {
     Q_UNUSED(collection);
     if (changedAttributes.contains("AccessRights")) {
